import { IDeniedField } from '../core';
import { Field } from '../model/field';
import { Datasheet } from '../model';
/**
 * Get information about a specified field.
 * Rerendering is triggered when a field property changes.
 *
 * If no ID is passed in, undefined is returned.
 *
 * @param fieldId The ID for this field.
 * @returns
 *
 * ### Example
 * ```js
 * import { useField } from '@apitable/widget-sdk';
 *
 * // show field name
 * function FieldName() {
 *   const field = useField('fldXXXXXXX');
 *   return <p>{field.name}</p>
 * }
 * ```
 *
 */
export declare function useField(fieldId: string | undefined): Field | undefined;
/**
 * ## Support for loading the corresponding datasheet data field.
 *
 * @param datasheet Datasheet instance, by {@link useDatasheet} get.
 * @param fieldId The ID for this field
 * @returns
 *
 *
 * ### Example
 * ```js
 * import { useField, useDatasheet } from '@apitable/widget-sdk';
 *
 * // show field name corresponding to the datasheetId(dstXXXXXXXX) datasheet
 * function FieldName() {
 *   const datasheet = useDatasheet('dstXXXXXXXX');
 *   const field = useField(datasheet, 'fldXXXXXXX');
 *   return <p>{field.name}</p>
 * }
 *
 * ```
 */
export declare function useField(datasheet: Datasheet | undefined, fieldId: string | undefined): Field | undefined;
/** @internal */
export declare function createDeniedField(): IDeniedField;
//# sourceMappingURL=use_field.d.ts.map