import { Datasheet, Field } from '../model';
/**
 * Get information of primary field.
 * Rerendering is triggered when a field property changes.
 *
 * @returns primary field info.
 *
 * ### Example
 * ```js
 * import { usePrimaryField, useDatasheet } from '@apitable/widget-sdk';
 *
 * // Show primary field name
 * function PrimaryFieldName() {
 *   const field = usePrimaryField();
 *   return <p>{field.name}</p>
 * }
 *
 * // Show corresponding datasheetId(dstXXXXXXXX) Name of the primary field of the datasheet
 * function DatasheetPrimaryFieldName() {
 *   const useDatasheet = useDatasheet('dstXXXXXXXX');
 *   const field = usePrimaryField(useDatasheet);
 *   return <p>{field.name}</p>
 * }
 * ```
 *
 */
export declare function usePrimaryField(datasheet?: Datasheet): Field | null;
//# sourceMappingURL=use_primary_field.d.ts.map