import { Record } from '../model/record';
import { Datasheet } from '../model';
/**
 * Gets information of a specified record.
 * Rerendering is triggered when the value of record, field property changes.
 *
 * If not ID is passed in, undefined is returned.
 *
 * @param recordId The ID for this record.
 * @returns
 *
 * ### Example
 * ```js
 * import { useRecord } from '@apitable/widget-sdk';
 *
 * // Show record title
 * function RecordTitle() {
 *   const record = useRecord('recXXXXXXX');
 *   return <p>{record.title}</p>
 * }
 * ```
 *
 */
export declare function useRecord(recordId: string | undefined): Record;
/**
 * ## Support for loading the corresponding datasheet data record.
 *
 * @param datasheet Datasheet instance, by {@link useDatasheet} get.
 * @param recordId The ID for this record.
 * @returns
 *
 * ### Example
 * ```js
 * import { useRecord, useDatasheet } from '@apitable/widget-sdk';
 *
 * // Show the primary key of record the corresponding to the datasheetId(dstXXXXXXXX) datasheet
 * function RecordTitle() {
 *   const datasheet = useDatasheet('dstXXXXXXXX);
 *   const record = useRecord('recXXXXXXX');
 *   return <p>{record.title}</p>
 * }
 * ```
 *
 */
export declare function useRecord(datasheet: Datasheet, recordId: string | undefined): Record;
//# sourceMappingURL=use_record.d.ts.map