export interface ISession {
    /** Current Login User Information */
    user: {
        id: string | undefined;
        name: string | undefined;
        email: string | undefined;
        avatar: string | undefined;
    };
}
/**
 * Get information about the current users of the widget.
 *
 * Notes: Since the datasheet can be share out, the id, name, avatar, ect. of the user information in the case of
 * not logged in is undefined.
 *
 * @returns
 *
 * ### Example
 * ```js
 * import { useSession } from '@apitable/widget-sdk';
 *
 * // Show the currently users name of the widget.
 * function Meta() {
 *   const session = useSession();
 *   return (<div>
 *     <p>{session.user.name}</p>
 *   </div>);
 * }
 * ```
 *
 */
export declare function useSession(): ISession;
//# sourceMappingURL=use_session.d.ts.map