import { Datasheet } from '../model';
/**
 * Gets the ID of all view of the currently datasheet.
 * Rerendering is triggered when the number of views changes.
 *
 * @returns
 *
 * ### Example
 * ```js
 * import { useViewIds, useDatasheet } from '@apitable/widget-sdk';
 *
 * // Display the total number of views
 * function ViewCount() {
 *   const viewIds = useViewIds();
 *   return <p>There are currently {viewIds.length} views</p>;
 * }
 * // Displays the total number of views corresponding to the datasheetId(dstXXXXXXXX) datasheet
 * function DatasheetViewCount() {
 *   const datasheet = useDatasheet('dstXXXXXXXX');
 *   const viewIds = useViewIds(datasheet);
 *   return <p>There are currently {viewIds.length} views</p>;
 * }
 * ```
 *
 */
export declare function useViewIds(datasheet?: Datasheet): string[];
//# sourceMappingURL=use_view_ids.d.ts.map