import { IViewProperty } from '../core';
import { IFilterInfo, IGroupInfo, ISortInfo, ViewType } from '../interface/view_types';
import { Datasheet } from '../model';
export interface IViewMeta {
    id: string;
    type: ViewType;
    name: string;
    hidden?: boolean;
    groupInfo?: IGroupInfo;
    filterInfo?: IFilterInfo;
    sortInfo?: ISortInfo;
}
/** @internal */
export declare const pickViewProperty: (view: IViewProperty) => IViewMeta;
/**
 * Beta API`, possible future changes.
 *
 * Gets the metadata property of the view.
 * Pass in a viewId, and return undefined when the viewId is illegal or does not exist.
 * Rerendering is triggered when the metadata property changes.
 *
 * @param viewId Need to get the view ID of the metadata property
 * @returns
 *
 * ### Example
 * ```js
 * import { useViewMeta, useActiveViewId } from '@apitable/widget-sdk';
 *
 * // Show name of the currently view.
 * function ViewName() {
 *   const activeViewId = useActiveViewId();
 *   const viewMeta = useViewMeta(activeViewId);
 *   return <p>Current view name: {viewMeta?.name}</p>;
 * }
 *
 * ```
 *
 */
export declare function useViewMeta(viewId: string | undefined): IViewMeta;
/**
 * ## Support getting the metadata property of the corresponding datasheet view.
 *
 * @param datasheet Datasheet instance, by {@link useDatasheet} get.
 * @param viewId Need to get the view ID of the metadata property
 * @returns
 *
 * ### Example
 * ```js
 * import { useViewMeta, useDatasheet } from '@apitable/widget-sdk';
 *
 * // Show the current view name of the corresponding datasheetId(dstXXXXXXXX) datasheet.
 * function ViewName() {
 *   const datasheet = useDatasheet('dstXXXXXXXX');
 *   const viewMeta = useViewMeta(datasheet, 'viwXXXXXXX');
 *   return <p>Current view name: {viewMeta?.name}</p>;
 * }
 * ```
 *
 */
export declare function useViewMeta(datasheet: Datasheet | undefined, viewId: string | undefined): IViewMeta;
//# sourceMappingURL=use_view_meta.d.ts.map