import { ICollaCommandExecuteResult, ICollaCommandOptions, IUnitInfo, IPageParams, ILabs, IShareInfo, IDatasheetMap, IViewRow, IMirrorMap, IUserInfo } from '../core';
import { WidgetLoadError } from '../initialize_widget';
import { IDatasheetClient, IDatasheetMainSimple, IExpandRecordProps, IWidgetConfigIframe, IWidgetDashboardState } from '../interface';
import { IExpireCalcCachePayload } from '../store';
import { IResponse, WidgetMessageType, IContentWindow, ISyncOperations, IInitResponse, MouseListenerType } from './interface';
declare class WidgetMessageBase {
    widgetId: string;
    /** As the window for sending messages */
    private contentWindow;
    private listenEvents;
    constructor(widgetId: string);
    /**
     * Send a message.
     * @param type
     * @param data
     */
    emit(type: WidgetMessageType, data: IResponse): void;
    on(type: WidgetMessageType, callback: (data: IResponse) => void): void;
    setContentWindow(contentWindow: IContentWindow): void;
}
declare class WidgetMessage extends WidgetMessageBase {
    connected: boolean;
    constructor(widgetId: string);
    /**
     * The widget initializes and goes to the main application to get the data.
     */
    initWidget(): Promise<IInitResponse>;
    /**
     * Listening to operations pushes from autonomous applications.
     * @param callback
     */
    onSyncOperations(callback: (res: IResponse<ISyncOperations>) => void): void;
    /**
     * Listening for config update messages from the main application.
     * @param callback
     */
    onSyncWidgetConfig(callback: (res: IResponse<IWidgetConfigIframe>) => void): void;
    /**
     * @param callback
     */
    onRefreshWidget(callback: (res: IResponse<string>) => void): void;
    onRefreshSnapshot(callback: (datasheetId: string) => void): void;
    /**
     * Synchronize config data to the main application.
     */
    syncWidgetConfig(config: IWidgetConfigIframe): void;
    /**
     * The operation generated by synchronizing the collaboration data to the main application.
     */
    syncCmd(cmdOptions: ICollaCommandOptions): Promise<ICollaCommandExecuteResult<any>>;
    /**
     * Listening to datasheet client update messages from the main application.
     */
    onSyncDatasheetClient(callback: (res: IDatasheetClient) => void): void;
    /**
     * Listening for unitInfo update messages from the main application.
     */
    onSyncUnitInfo(callback: (res: IUnitInfo) => void): void;
    /**
     * Listening for pageParams update messages from the main application.
     */
    onSyncPageParams(callback: (res: IPageParams) => void): void;
    /**
     * Listening for labs update messages from the main application.
     */
    onSyncLabs(callback: (res: ILabs) => void): void;
    /**
     * Listening for share update messages from the main application.
     */
    onSyncShare(callback: (res: IShareInfo) => void): void;
    /**
     * Listening for dashboard-related data updates from the main application.
     * @param callback
     */
    onSyncDashboard(callback: (dashboard: IWidgetDashboardState) => void): void;
    /**
     * Listening for mirrorMap update messages from the main application.
     */
    onSyncMirrorMap(callback: (res: IMirrorMap) => void): void;
    /**
     * Load other related table data, initialize for the first time.
     */
    loadOtherDatasheetInit(datasheetId: string): void;
    /**
     * Listening for initialization returns from other related table data.
     */
    onLoadOtherDatasheet(callback: (res: IDatasheetMap) => void): void;
    /**
     * Listening for updates returned from other related table data (in addition to snapshot).
     */
    onDatasheetSimpleUpdate(callback: (res: {
        [datasheetId: string]: IDatasheetMainSimple;
    }) => void): void;
    /**
     * Trigger expandRecord.
     */
    expandRecord(expandRecordParams: IExpandRecordProps): void;
    /**
     * Mouse in and mouse out widgets iframe.
     */
    mouseListener(type: MouseListenerType): void;
    /**
     * Listening for cache updates from the main application.
     */
    onSyncCalcCache(callback: (res: {
        datasheetId: string;
        viewId: string;
        cache: IViewRow[];
    }) => void): void;
    /**
     * Initializing the view calculation cache.
     * @param datasheetId
     * @param viewId
     */
    initCache(datasheetId: string, viewId: string): void;
    /**
     * Expand to enter the developer mode pop-up window.
     */
    expandDevConfig(): void;
    /**
     * Send loading widget results
     * @param widgetId
     * @param devUrl
     * @param widgetPackageId
     * @param refresh
     */
    sendLoadWidget(error?: WidgetLoadError): void;
    /**
     * Listening to loading widget.
     * @param callback
     */
    onLoadWidget(): void;
    /**
     * Listening for marker cache expiration.
     * @param callback
     */
    onCalcExpire(callback: (params: IExpireCalcCachePayload) => void): void;
    /**
     * Listening for synchronize data related to the main application userInfo
     * @param userInfo
     */
    onSyncUserInfo(callback: (res: IUserInfo) => void): void;
}
export declare let widgetMessage: WidgetMessage;
export declare const initWidgetMessage: (widgetId: string) => WidgetMessage;
export {};
//# sourceMappingURL=widget_message.d.ts.map