import { IWidgetContext } from '../interface';
/**
 * Datasheet row operations and information.
 *
 * Get the rows record, you can use {@link useRecord} (querying single record data), {@link useRecords} (batch query of record data)
 */
export declare class Record {
    datasheetId: string;
    private wCtx;
    recordId: string;
    /**
     * @hidden
     */
    constructor(datasheetId: string, wCtx: IWidgetContext, recordId: string);
    private getRecordData;
    private getFieldRole;
    /**
     * Gets the cell value of the given field for this record.
     *
     * @param fieldId The field ID whose cell value you'd like to get.
     * @returns
     *
     * #### Example
     * ```js
     * const cellValue = myRecord.getCellValue(mySingleLineTextFieldId);
     * console.log(cellValue);
     * // => 'cell value'
     * ```
     */
    getCellValue(fieldId: string): any;
    /**
     * @hidden
     */
    _getCellValue(fieldId: string): any;
    /**
     * Gets the cell value of the given field of record, and convert to string type.
     *
     * @returns
     *
     * #### Example
     * ```js
     * const stringValue = myRecord.getCellValueString(myNumberFieldId);
     * console.log(stringValue);
     * // => '42'
     * ```
     */
    getCellValueString(fieldId: string): string | null;
    /**
     *
     * The URL address of the record, which you can access in your browser,
     * opens the Wiggle Table interface and locates the record
     *
     * @param viewId
     * @returns
     *
     */
    url(viewId?: string): string;
    /**
     * The ID for this record.
     */
    get id(): string;
    /**
     * The primary cell value in this record, formatted as a string.
     *
     * @returns
     *
     * #### Example
     * ```js
     * console.log(myRecord.title);
     * // => '42'
     * ```
     */
    get title(): string | null;
    /**
     * The number of comments on this record.
     * @returns
     *
     */
    get commentCount(): number;
}
//# sourceMappingURL=record.d.ts.map