/// <reference types="socket.io-client" />
import { CollaCommandManager, ComputeRefManager, Engine, IJOTAction, IReduxState, IResourceOpsCollect, OPEventManager, ResourceStashManager, ResourceType, RoomService, UndoManager } from '../core';
import { Store } from 'redux';
import { IResourceService, IServiceError } from './interface';
export declare const remoteActions2Operation: (actions: IJOTAction[]) => {
    cmd: string;
    actions: IJOTAction[];
};
export declare class ResourceService implements IResourceService {
    store: Store<IReduxState>;
    onError: IServiceError;
    socket: SocketIOClient.Socket;
    roomService: RoomService;
    commandManager: CollaCommandManager;
    initialized?: boolean;
    undoManager: UndoManager;
    resourceStashManager: ResourceStashManager;
    opEventManager: OPEventManager;
    computeRefManager: ComputeRefManager;
    reportSocketError: boolean;
    roomIOClear: boolean;
    roomLastSendTime?: number;
    firstRoomInit: boolean;
    constructor(store: Store<IReduxState>, onError: IServiceError);
    init(): void;
    destroy(): void;
    static getResourceFetchAction(resourceType: ResourceType): any;
    switchResource(params: {
        from?: string;
        to: string;
        resourceType: ResourceType;
        extra?: {
            [key: string]: any;
        };
    }): Promise<void>;
    fetchResource(to: string, resourceType: ResourceType, overWrite?: boolean, extra?: {
        [key: string]: any;
    }): Promise<void>;
    applyOperations(store: Store<IReduxState>, resourceOpsCollects: IResourceOpsCollect[]): void;
    /**
     * @description Simply handle the creation and destruction of rooms, and the creation of undoManager.
     * The point of this method is that it is the same as opening a datasheet,
     * but the concept of destroying/creating a room cannot exist in the "template", so this method is more pure,
     * only call when the concept of room is met.
     * @param {string} to
     * @returns {Promise<void>}
     * @private
     */
    private switchRoom;
    /**
     * @description undoManger is bound to the main resource that created the room,
     * and when switching the resource, it is necessary to instantiate undoManager,
     * and bind undoManger to commandManager.
     * @param {string} resourceId
     */
    createUndoManager(resourceId: string): void;
    /**
     * @description Determine if the current operation is taking place "in the template",
     * no resource in the template needs to create/destroy the room.
     * @returns {boolean}
     * @private
     */
    private allowSwitchRoom;
    private createSocket;
    getCollaEngine(resourceId: string): Engine | undefined;
    localOperationDispatch: (resourceOpsCollects: IResourceOpsCollect[]) => void;
    /**
     * @desc The method that applies command to generate an op, which is passed in as a callback function when the CommandManager is initialized.
     * This method is responsible for only two things.
     * 1. Apply the op generated by command to the local.
     * 2. Send op to intermediate layer via socket.
     * @param resourceOpsCollects
     */
    operationExecuted: (resourceOpsCollects: IResourceOpsCollect[]) => void;
    private createCommandManager;
    private beforeUnload;
    private bindBeforeUnload;
    private unBindBeforeUnload;
    /**
     * @description 1. delete the resource data on the store;
     * 2. delete the resource from collaEngineMap provided that the engine has issued an op
     * @param {string} resourceId
     */
    reset(resourceId: string): void;
    onNewChanges(resourceType: ResourceType, resourceId: string, actions: IJOTAction[]): void;
    /**
     * @description Create a collaborative engine (collaEngine) for each resource.
     * @param {string} resourceId
     * @param {ResourceType} resourceType
     * @returns
     */
    createCollaEngine(resourceId: string, resourceType: ResourceType): boolean;
    getCollaEngineKeys(): IterableIterator<string>;
    checkRoomExist(): boolean;
}
//# sourceMappingURL=service.d.ts.map