import { IFieldPicker } from '../../interface';
/**
 * A field selector component that can select the fields inside the corresponding view ID.
 *
 * @returns
 *
 * #### Example
 *
 * Common usage.
 * ``` ts
 * import React, { useState } from 'react';
 * import { FieldPicker, useActiveViewId } from '@apitable/widget-sdk';
 * const Example = () => {
 *   const viewId = useActiveViewId();
 *   const [fieldId, setFieldId] = useState()
 *   return <FieldPicker viewId={viewId} fieldId={fieldId} onChange={option => setFieldId(option.value)} />
 * }
 * ```
 *
 * Use {@link useCloudStorage} implementing persistent storage.
 * ``` ts
 * import React, { useState } from 'react';
 * import { FieldPicker, useActiveViewId, useCloudStorage } from '@apitable/widget-sdk';
 * const ExampleCloud = () => {
 *   const viewId = useActiveViewId();
 *   const [fieldId, setFieldId] = useCloudStorage('selectFieldId');
 *   return  <FieldPicker viewId={viewId} fieldId={fieldId} onChange={option => setFieldId(option.value)} />;
 * };
 * ```
 *
 */
export declare function FieldPicker(props: IFieldPicker): JSX.Element;
//# sourceMappingURL=field_picker.d.ts.map